@@ -37,6 +37,18 @@ if FOAM_VERSION( ">=", "010700" ):
     pass
 
 
+#--------------------------------------------------------------------------------------
+if FOAM_VERSION( ">=", "020000" ):
+    from laplacianFlux.r2_0_0 import * 
+    pass
+
+
+#--------------------------------------------------------------------------------------
+if FOAM_VERSION( ">=", "020100" ):
+    from laplacianFlux.r2_1_0 import * 
+    pass
+
+
 #--------------------------------------------------------------------------------------
 def entry_point():
     try:
